import matplotlib
matplotlib.use('Agg')

def consolidate(fname):

    import h5py
    import numpy

    with h5py.File(fname,'r+') as f:
        return {field:numpy.array(f[field])
                for field in f}

def h5_to_png(fname):

    import matplotlib.pyplot as plt

    print fname

    data = consolidate(fname)

    f, axes = plt.subplots(3)
    y_vals = ['density',
              'pressure',
              'x_velocity']

    for n in range(3):
        if y_vals[n] == 'x_velocity':
            axes[n].plot(data['grid'],
                         data[y_vals[n]])
        else:
            axes[n].semilogy(data['grid'],
                             data[y_vals[n]])
        axes[n].set_ylabel(y_vals[n])
    f.suptitle('t = '+str(data['time'][0]))
    f.savefig(fname.replace('.h5','.png'))

def all_h5_to_png():

    import glob
    from joblib import Parallel, delayed

    flist = glob.glob('*.h5')
    Parallel(n_jobs=-2)(delayed(h5_to_png)(fname)
                        for fname in flist)

def create_animted_gif():

    import imageio
    import glob
    import re

    def extract_number(fname):

        return int(re.search(r'(\d+)',fname).group(1))

    flist = sorted(glob.glob('snapshot_*.png'),
                   key=extract_number)
    with imageio.get_writer('animated.gif',
                            mode='I') as writer:
        for fname in flist:
            image = imageio.imread(fname)
            writer.append_data(image)    

def main():

    all_h5_to_png()
    create_animted_gif()

if __name__ == '__main__':

    main()

    
