#ifndef SIM_DATA_HPP
#define SIM_DATA_HPP 1

#include "source/newtonian/one_dimensional/physical_geometry_1d.hpp"
#include "source/newtonian/one_dimensional/pcm1d.hpp"
#include "source/newtonian/one_dimensional/hdsim.hpp"
#include "source/newtonian/common/ideal_gas.hpp"
#include "source/newtonian/common/hllc.hpp"
#include "source/newtonian/one_dimensional/eulerian1d.hpp"
#include "source/newtonian/one_dimensional/rigid_wall_1d.hpp"
#include "source/newtonian/one_dimensional/zero_force_1d.hpp"
#include "source/misc/simple_io.hpp"

class SmoothInjection: public SourceTerm1D
{
public:

  SmoothInjection(double D,
		  double eta,
		  double v_w,
		  double GM,
		  const PhysicalGeometry1D& pg); 

  Conserved operator()
  (vector<double> const& vertices,
   vector<Primitive> const& cells,
   size_t point,
   double t,
   double dt) const;

private:
  const double D_;
  const double eta_;
  const double v_w_;
  const double GM_;
  const PhysicalGeometry1D& pg_;
};

class Ratchet: public BoundaryConditions1D
{
public:

  Conserved CalcFlux(const vector<double>& vertices,
		     const vector<Primitive>& cells,
		     const RiemannSolver& rs,
		     vector<double> const& vertex_veclocity,
		     int i) const;
};

class SimData
{
public:

  SimData(void);

  hdsim1D& getSim(void);

private:
  const SphericalSymmetry1D pg_;
  const PCM1D sr_;
  const IdealGas eos_;
  const Hllc rs_;
  const Eulerian1D vm_;
  const Ratchet bc_;
  const SmoothInjection source_;
  const vector<double> grid_;
  hdsim1D sim_;
};

#endif // SIM_DATA_HPP
